try:
    from Products.CMFCore.CMFCorePermissions import setDefaultRoles
except ImportError:
    from Products.CMFCore.permissions import setDefaultRoles

PROJECTNAME = "PGnuplot"
DEFAULT_ADD_CONTENT_PERMISSION = "Add PGnuplot"
product_globals=globals()

setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner',))
